fn human_render_slot(
out: impl Write,
slot: Option<Slot>,
entry: &BootEntry,
image: &ImageStatus,
host_status: &HostStatus,
verbose: bool,
) -> Result<()>Expand description
Write the data for a container image based status.
fn human_render_slot(
out: impl Write,
slot: Option<Slot>,
entry: &BootEntry,
image: &ImageStatus,
host_status: &HostStatus,
verbose: bool,
) -> Result<()>Write the data for a container image based status.