render_cached_update

Function render_cached_update 

fn render_cached_update(
    out: impl Write,
    cached: &ImageStatus,
    current: &ImageStatus,
    prefix_len: usize,
) -> Result<()>
Render cached update information, showing what update is available.

This is populated by a previous bootc upgrade --check that found a newer image in the registry. We only display it when the cached digest differs from the currently deployed image.